@@ -119,23 +119,17 @@ class Server:
 
         from mxcubeweb.routes.csp_report import init_route as init_csp_route
         from mxcubeweb.routes.harvester import init_route as init_harvester_route
-        from mxcubeweb.routes.lims import init_route as init_lims_route
         from mxcubeweb.routes.login import init_route as init_login_route
         from mxcubeweb.routes.main import init_route as init_main_route
         from mxcubeweb.routes.queue import init_route as init_queue_route
         from mxcubeweb.routes.ra import init_route as init_ra_route
         from mxcubeweb.routes.samplecentring import init_route as init_sampleview_route
-        from mxcubeweb.routes.samplechanger import (
-            init_route as init_samplechanger_route,
-        )
         from mxcubeweb.routes.workflow import init_route as init_workflow_route
 
         url_root_prefix = "/mxcube/api/v0.1"
 
         Server._register_route(init_csp_route, mxcube, f"{url_root_prefix}/csp")
 
-        Server._register_route(init_lims_route, mxcube, f"{url_root_prefix}/lims")
-
         Server._register_route(init_login_route, mxcube, f"{url_root_prefix}/login")
 
         Server._register_route(init_main_route, mxcube, f"{url_root_prefix}")
@@ -154,12 +148,6 @@ class Server:
             f"{url_root_prefix}/sampleview",
         )
 
-        Server._register_route(
-            init_samplechanger_route,
-            mxcube,
-            f"{url_root_prefix}/sample_changer",
-        )
-
         Server._register_route(
             init_harvester_route, mxcube, f"{url_root_prefix}/harvester"
         )
